@@ -8,7 +8,7 @@ import os
 # except ImportError:
 #     from sklearn.utils import _safe_indexing
 
-    
+from pathlib import Path    
 from pycaret.classification import *
 from sklearn.metrics import recall_score
 from mlflow.models.signature import infer_signature
@@ -27,6 +27,7 @@ TARGET_COL = 'result'
 REMOTE_TRACKING_URI = 'http://ec2-3-10-175-206.eu-west-2.compute.amazonaws.com:5000/'
 
 
+
                     # 'http://ec2-3-10-210-150.eu-west-2.compute.amazonaws.com:5000/'
 
 
@@ -35,40 +36,50 @@ def get_plots(model):
 
     model_attributes = dir(model)
 
-    plot_model(model, plot = 'confusion_matrix', save=True)
-    cm = os.path.join(os.getcwd(), 'plots/Confusion Matrix.png')
-    mlflow.log_artifact(cm)
+    plot_dir = os.path.join(os.getcwd(), 'plots')
+    Path(plot_dir).mkdir(parents=True, exist_ok=True)
+
+    plot_model(model, plot = 'confusion_matrix', save=plot_dir)
+    cm = os.path.join(plot_dir, 'Confusion Matrix.png')
+    # mlflow.log_artifact(cm)
     # log_artifact(cm)
 
-    plot_model(model, plot = 'class_report', save=True) 
-    cr = os.path.join(os.getcwd(), 'plots/Class Report.png')
-    mlflow.log_artifact(cr)  
+    plot_model(model, plot = 'class_report', save=plot_dir) 
+    cr = os.path.join(plot_dir, 'Class Report.png')
+    # mlflow.log_artifact(cr)  
     # log_artifact(cr)
     
 
 
     if 'predict_proba' in model_attributes:
         try:
-            plot_model(model, plot = 'auc', save=True)
-            auc = os.path.join(os.getcwd(), 'plots/AUC.png')
-            mlflow.log_artifact(auc) 
+            plot_model(model, plot = 'auc', save=plot_dir)
+            auc = os.path.join(plot_dir, 'AUC.png')
+            # mlflow.log_artifact(auc) 
 
-            plot_model(model, plot = 'pr', save=True) 
-            pr = os.path.join(os.getcwd(), 'plots/Precision Recall.png')
-            mlflow.log_artifact(pr)
+            plot_model(model, plot = 'pr', save=plot_dir) 
+            pr = os.path.join(plot_dir, 'Precision Recall.png')
+            # mlflow.log_artifact(pr)
 
-            plot_model(model, plot = 'calibration', save=True) 
-            cc = os.path.join(os.getcwd(), 'plots/Calibration Curve.png')
-            mlflow.log_artifact(cc)
+            plot_model(model, plot = 'calibration', save=plot_dir) 
+            cc = os.path.join(plot_dir, 'Calibration Curve.png')
+            # mlflow.log_artifact(cc)
         except:
             pass
   
 
     
     if 'feature_importances_' in model_attributes:  
-        plot_model(model, plot = 'feature', save=True)  
-        fi = os.path.join(os.getcwd(), 'plots/Feature Importance.png')
-        mlflow.log_artifact(fi)
+        plot_model(model, plot = 'feature', save=plot_dir)  
+        fi = os.path.join(plot_dir, 'Feature Importance.png')
+        # mlflow.log_artifact(fi)
+    
+
+
+
+    mlflow.log_artifact(plot_dir)
+
+
 
 
 
@@ -169,6 +180,7 @@ def objective(trial, df, study_name, model_mode):
 
 
         mlflow.log_metrics(metrics)
+        
 
         try:
             # mlflow.set_tag('features', features)
